%define realname qwt
%define major    6.3

%bcond_without  qt5
%bcond_without  qt6

Name:           libqwt
Version:        6.3.0
Release:        %mkrel 1
Summary:        2D plotting widget extension to the Qt GUI
License:        Qwt License 1.0
Group:          System/Libraries
Url:            https://qwt.sourceforge.io/
Source:         https://downloads.sourceforge.net/%{realname}/%{realname}-%{version}.tar.bz2
## upstream patches

## upstreamable patches
# fix pkgconfig support
Patch50:        qwt-pkgconfig.patch
# use QT_INSTALL_ paths instead of custom prefix
Patch51:        qwt-6.1.5-qt_install_paths.patch
# parallel-installable qt5 and qt6 version
Patch52:        qwt-qt5.patch
#
Patch53:        qwt-6.1.3-no_rpath.patch

%if %{with qt5}
### Qt5 BuildRequires
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Designer)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Widgets)
%endif

%if %{with qt6}
### Qt6 BuildRequires
BuildRequires:  cmake(Qt6Concurrent)
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6Designer)
BuildRequires:  cmake(Qt6OpenGL)
BuildRequires:  cmake(Qt6PrintSupport)
BuildRequires:  cmake(Qt6Svg)
BuildRequires:  cmake(Qt6Widgets)
%endif

%description
Qwt is an extension to the Qt GUI library from Troll Tech AS.
The Qwt library contains widgets and components which are
primarily useful for technical and scientific purposes.
It includes a 2-D plotting widget, different kinds of sliders,
and much more.

#------------------------------------------------------------------------------
%if %{with qt5}

%define libname_qt5 %mklibname %realname-qt5_ %{major}

%package -n     %{libname_qt5}
Summary:        2D plotting widget extension to the Qt5 GUI
Group:          System/Libraries

%description -n %{libname_qt5}
Qwt is an extension to the Qt5 GUI library from Troll Tech AS.
The Qwt library contains widgets and components which are
primarily useful for technical and scientific purposes.
It includes a 2-D plotting widget, different kinds of sliders,
and much more.

This package provides the runtime library.

%files -n %{libname_qt5}
%doc CHANGES* README
%license COPYING
%{_qt5_libdir}/libqwt-qt5.so.%{major}{,.*}

#------------------------------------------------------------------------------

%define libname_qt5_designer %{_lib}qwt-qt5-designer-plugin

%package -n     %{libname_qt5_designer}
Summary:        Qwt designer plugin
Group:          Development/KDE and Qt
Provides:       qt5-designer-plugin-qwt = %{version}-%{release}
Provides:       qt5designer-qwt-plugin = %{version}-%{release}
%ifarch %ix86 %arm32
Obsoletes:      lib64qwt-qt5-designer-plugin < 6.2.0-4
%endif
Conflicts:      %{_lib}qwt-qt5_6 < 6.2.0
Conflicts:      %{_lib}qwt-qt5_6.2 < 6.2.0-2

%description -n %{libname_qt5_designer}
Qwt is an extension to the Qt5 GUI library from Troll Tech AS.
The Qwt library contains widgets and components which are
primarily useful for technical and scientific purposes.
It includes a 2-D plotting widget, different kinds of sliders,
and much more.

This package provides Qwt plugin for Qt5 designer.

%files -n %{libname_qt5_designer}
%{_qt5_plugindir}/designer/libqwt_designer_plugin.so

#------------------------------------------------------------------------------

%define libnamedev_qt5 %mklibname qwt-qt5 -d

%package -n     %{libnamedev_qt5}
Summary:        Development tools for programs which uses Qt5 Qwt Widget set
Group:          System/Libraries
Requires:       %{libname_qt5} = %{version}
Provides:       libqwt-qt5-devel = %{version}-%{release}

%description -n %{libnamedev_qt5}
The %{libnamedev_qt5} package contains the header files and static libraries
necessary for developing programs using the Qt5 Qwt Widget set.

If you want to develop programs which will use this set of widgets,
you should install this package. You need also to install the libqwt-qt5 package.

%files -n %{libnamedev_qt5}
%doc COPYING
%doc examples
%docdir %{_qt5_docdir}/html/
%{_qt5_docdir}/html/qwt/
%{_qt5_includedir}/qwt/
%{_qt5_libdir}/libqwt-qt5.so
%{_qt5_libdir}/pkgconfig/Qt5Qwt6.pc
%{_qt5_archdatadir}/mkspecs/*
%{_mandir}/man3/*
%endif

#------------------------------------------------------------------------------
%if %{with qt6}

%define libname_qt6 %mklibname %realname-qt6_ %{major}

%package -n     %{libname_qt6}
Summary:        2D plotting widget extension to the Qt6 GUI
Group:          System/Libraries

%description -n %{libname_qt6}
Qwt is an extension to the Qt6 GUI library from Troll Tech AS.
The Qwt library contains widgets and components which are
primarily useful for technical and scientific purposes.
It includes a 2-D plotting widget, different kinds of sliders,
and much more.

This package provides the runtime library.

%files -n %{libname_qt6}
%doc CHANGES* README
%license COPYING
%{_qt6_libdir}/libqwt-qt6.so.%{major}{,.*}

#------------------------------------------------------------------------------

%define libname_qt6_designer %{_lib}qwt-qt6-designer-plugin

%package -n     %{libname_qt6_designer}
Summary:        Qwt designer plugin
Group:          Development/KDE and Qt
Provides:       qt6-designer-plugin-qwt = %{version}-%{release}
Provides:       qt6designer-qwt-plugin = %{version}-%{release}
%ifarch %ix86 %arm32
Obsoletes:      lib64qwt-qt6-designer-plugin < 6.2.0-4
%endif

%description -n %{libname_qt6_designer}
Qwt is an extension to the Qt6 GUI library from Troll Tech AS.
The Qwt library contains widgets and components which are
primarily useful for technical and scientific purposes.
It includes a 2-D plotting widget, different kinds of sliders,
and much more.

This package provides Qwt plugin for Qt6 designer.

%files -n %{libname_qt6_designer}
%{_qt6_plugindir}/designer/libqwt_designer_plugin.so

#------------------------------------------------------------------------------

%define libnamedev_qt6 %mklibname qwt-qt6 -d

%package -n     %{libnamedev_qt6}
Summary:        Development tools for programs which uses Qt6 Qwt Widget set
Group:          System/Libraries
Requires:       %{libname_qt6} = %{version}
Provides:       libqwt-qt6-devel = %{version}-%{release}
Provides:       qwt-qt6-devel = %{version}-%{release}

%description -n %{libnamedev_qt6}
The %{libnamedev_qt6} package contains the header files and static libraries
necessary for developing programs using the Qt6 Qwt Widget set.

If you want to develop programs which will use this set of widgets,
you should install this package. You need also to install the libqwt-qt6 package.

%files -n %{libnamedev_qt6}
%doc COPYING
%doc examples
%docdir %{_qt6_docdir}/html/
%{_qt6_docdir}/html/qwt/
%{_qt6_includedir}/qwt/
%{_qt6_libdir}/libqwt-qt6.so
%{_qt6_libdir}/pkgconfig/Qt6Qwt6.pc
%{_qt6_archdatadir}/mkspecs/*
%{_mandir}/man3/*
%endif
#------------------------------------------------------------------------------

%prep
%autosetup -p1 -n %{realname}-%{version}

%build
### Qt5 Build ###
mkdir -p qt5
pushd qt5
%qmake_qt5 QWT_CONFIG+=QwtPkgConfig ..
%make_build
popd

### Qt6 Build ###
mkdir -p qt6
pushd qt6
%qmake_qt6 QWT_CONFIG+=QwtPkgConfig ..
%make_build
popd

%install
### Qt5 Install ###
%make_install INSTALL_ROOT=%{buildroot} -C qt5

rm -rf %{buildroot}%{_qt5_libdir}/libqwt-qt5.so.%(echo %{major} | cut -d. -f1)

mv %{buildroot}%{_qt5_docdir}/html/html %{buildroot}%{_qt5_docdir}/html/qwt
mkdir -p %{buildroot}%{_mandir}
mv %{buildroot}%{_qt5_docdir}/html/man/man3 %{buildroot}%{_mandir}/

### Qt6 Install ###
%make_install INSTALL_ROOT=%{buildroot} -C qt6

rm -rf %{buildroot}%{_qt6_libdir}/libqwt-qt6.so.%(echo %{major} | cut -d. -f1)

# Last build "wins"
rm -rf %{buildroot}%{_mandir}/*
mv %{buildroot}%{_qt6_docdir}/html/html %{buildroot}%{_qt6_docdir}/html/qwt
mkdir -p %{buildroot}%{_mandir}
mv %{buildroot}%{_qt6_docdir}/html/man/man3 %{buildroot}%{_mandir}/


%changelog
* Tue Jul 22 2025 daviddavid <daviddavid> 6.3.0-1.mga10
+ Revision: 2258261
- new version: 6.3.0
- now libmajor is 6.3

* Sat Jun 28 2025 umeabot <umeabot> 6.2.0-5.mga10
+ Revision: 2218479
- Mageia 10 Mass Rebuild

* Sat Jun 17 2023 wally <wally> 6.2.0-4.mga9
+ Revision: 1962247
- fix qt5 and qt6 designer plugin pkg name

* Tue Dec 20 2022 daviddavid <daviddavid> 6.2.0-3.mga9
+ Revision: 1925445
- enable Qt6 support

* Tue Aug 09 2022 wally <wally> 6.2.0-2.mga9
+ Revision: 1876358
- split out Qt5 designer plugin

* Tue Aug 09 2022 wally <wally> 6.2.0-1.mga9
+ Revision: 1876351
- new version 6.2.0
- new lib major 6.2
- drop qt4 build
- no more libqwtmathml lib

* Mon Apr 04 2022 umeabot <umeabot> 6.1.5-4.mga9
+ Revision: 1843411
- Mageia 9 Mass Rebuild

* Fri Dec 18 2020 daviddavid <daviddavid> 6.1.5-3.mga8
+ Revision: 1660547
- rebuild for missing pkgs

* Thu Dec 17 2020 umeabot <umeabot> 6.1.5-2.mga8
+ Revision: 1658953
- Rebuild for new Qt5

* Tue Jul 14 2020 daviddavid <daviddavid> 6.1.5-1.mga8
+ Revision: 1605857
- new version: 6.1.5 (compatibility to Qt 5.15)

* Wed Feb 19 2020 umeabot <umeabot> 6.1.4-2.mga8
+ Revision: 1542751
- Mageia 8 Mass Rebuild

* Tue Jan 07 2020 daviddavid <daviddavid> 6.1.4-1.mga8
+ Revision: 1477035
- new version: 6.1.4

* Sat Jul 27 2019 daviddavid <daviddavid> 6.1.3-4.mga8
+ Revision: 1424478
- rebuild for new Qt5 headers path

* Sun Mar 31 2019 umeabot <umeabot> 6.1.3-3.mga7
+ Revision: 1383200
- Qt5 Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 6.1.3-2.mga7
+ Revision: 1299113
- Mageia 7 Mass Rebuild

* Wed Apr 18 2018 daviddavid <daviddavid> 6.1.3-1.mga7
+ Revision: 1219771
- new version: 6.1.3
- add Qt5 support

* Sat Feb 06 2016 umeabot <umeabot> 6.0.1-9.mga6
+ Revision: 941594
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 6.0.1-8.mga5
+ Revision: 749041
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 6.0.1-7.mga5
+ Revision: 681739
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 6.0.1-6.mga4
+ Revision: 507316
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 6.0.1-5.mga3
+ Revision: 358045
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Nov 18 2012 zezinho <zezinho> 6.0.1-4.mga3
+ Revision: 319481
- add conflicts with libqwt5

* Sun Nov 18 2012 zezinho <zezinho> 6.0.1-3.mga3
+ Revision: 319446
- conflict devel package and remove bad obsoletes

* Sat Nov 17 2012 zezinho <zezinho> 6.0.1-2.mga3
+ Revision: 319237
- obsoletes qwt5

* Sat Nov 17 2012 zezinho <zezinho> 6.0.1-1.mga3
+ Revision: 319010
- fix build
- update patch

* Fri Nov 16 2012 zezinho <zezinho> 5.2.2-3.mga3
+ Revision: 318996
- spec cleanup

* Tue Dec 27 2011 dmorgan <dmorgan> 5.2.2-2.mga2
+ Revision: 187989
- Rebuild against new qt4 and new include path

* Mon Dec 12 2011 mikala <mikala> 5.2.2-1.mga2
+ Revision: 181023
- Update tarball to 5.2.2
- sync patch0 with fedora's one
- drop patch1
- change spec layout
- fix description
- remove %%clean & %%defattr()

* Fri Apr 01 2011 ahmad <ahmad> 5.2.1-3.mga1
+ Revision: 79417
- drop old/unneeded scriptlets
- imported package libqwt


* Sat Feb 05 2011 Funda Wang <fwang@mandriva.org> 5.2.1-2mdv2011.0
+ Revision: 636050
- tighten BR

* Mon Aug 23 2010 Yuri Myasoedov <omerta13@mandriva.org> 5.2.1-1mdv2011.0
+ Revision: 572091
- New version 5.2.1

* Fri May 01 2009 Funda Wang <fwang@mandriva.org> 5.2.0-1mdv2010.0
+ Revision: 369350
- New version 5.2.0

* Fri Mar 13 2009 Funda Wang <fwang@mandriva.org> 5.1.1-1mdv2009.1
+ Revision: 354460
- rediff patch

* Tue Aug 05 2008 Funda Wang <fwang@mandriva.org> 5.1.1-1mdv2009.0
+ Revision: 263932
- New version 5.1.1

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Thu May 15 2008 Funda Wang <fwang@mandriva.org> 5.1.0-1mdv2009.0
+ Revision: 207499
- New version 5.1.0

* Wed Jan 02 2008 Olivier Blin <oblin@mandriva.com> 5.0.2-1mdv2008.1
+ Revision: 140928
- restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Sat Jul 21 2007 Funda Wang <fwang@mandriva.org> 5.0.2-1mdv2008.0
+ Revision: 54251
- New version
- renew file list
- Build qt4 version

* Mon Apr 23 2007 Lenny Cartier <lenny@mandriva.org> 5.0.1-1mdv2008.0
+ Revision: 17323
- Update to 5.0.1


* Tue Jan 23 2007 Lenny Cartier <lenny@mandriva.com> 5.0.0-1mdv2007.0
+ Revision: 112574
- Updated to 5.0.0

* Fri Aug 11 2006 Gaëtan Lehmann <glehmann@mandriva.org> 4.2.0-6mdv2007.0
+ Revision: 55477
- rebuild
- Import libqwt

* Mon Dec 12 2005 Helio Chissini de Castro <helio@mandriva.com> 4.2.0-5mdk
- Move designer plugins for proper place in lib or lib64

* Wed Oct 05 2005 Lenny Cartier <lenny@mandriva.com> 4.2.0-4mdk
- rebuild

* Wed Jul 27 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 4.2.0-3mdk
- build on x86_64
- fix buildrequires

* Sat Jun 25 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 4.2.0-2mdk
- use mkrel
- fix doc path warning

* Wed Mar 02 2005 Olivier Lahaye <olivier.lahaye1@free.Fr> 1mdk
- port spec to Mandrake 10.1

* Fri Feb 11 2005 Vitaly Lipatov <lav@altlinux.ru> 4.2.0-alt2
- move libraries to /usr/lib64, fix .so placement

* Fri Dec 03 2004 Vitaly Lipatov <lav@altlinux.ru> 4.2.0-alt1
- first build for ALT Linux Sisyphus

